@@ -417,7 +417,7 @@ globus_module_descriptor_t              globus_i_gsi_sysconfig_module;
 #endif
 
 /**
- * Generate a unqiue proxy file name
+ * Generate a unique proxy file name
  * @ingroup globus_gsi_system_config_defines
  * @hideinitializer
  * See globus_gsi_sysconfig_get_unique_proxy_filename() 
@@ -425,227 +425,126 @@ globus_module_descriptor_t              globus_i_gsi_sysconfig_module;
 #define     GLOBUS_GSI_SYSCONFIG_GET_UNIQUE_PROXY_FILENAME \
             globus_gsi_sysconfig_get_unique_proxy_filename
 
-#ifdef WIN32
+/**
+ * Determine the location of the vhost credentials directory
+ * @ingroup globus_gsi_system_config_defines
+ * @hideinitializer
+ * See globus_gsi_sysconfig_get_vhost_cred_dir()
+ */
+#define GLOBUS_GSI_SYSCONFIG_GET_VHOST_CRED_DIR \
+        globus_gsi_sysconfig_get_vhost_cred_dir
 
 globus_result_t
-globus_gsi_sysconfig_set_key_permissions_win32(
+GLOBUS_GSI_SYSCONFIG_SET_KEY_PERMISSIONS(
     char *                              filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_home_dir_win32(
+GLOBUS_GSI_SYSCONFIG_GET_HOME_DIR(
     char **                             home_dir);
 
 globus_result_t
-globus_gsi_sysconfig_file_exists_win32(
+GLOBUS_GSI_SYSCONFIG_FILE_EXISTS(
     const char *                        filename);
 
 globus_result_t
-globus_gsi_sysconfig_dir_exists_win32(
+GLOBUS_GSI_SYSCONFIG_DIR_EXISTS(
     const char *                        filename);
 
 globus_result_t
-globus_gsi_sysconfig_check_keyfile_win32(
+GLOBUS_GSI_SYSCONFIG_CHECK_KEYFILE(
     const char *                        filename);
 
 globus_result_t
-globus_gsi_sysconfig_check_certfile_win32(
+GLOBUS_GSI_SYSCONFIG_CHECK_CERTFILE(
     const char *                        filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_cert_dir_win32(
+GLOBUS_GSI_SYSCONFIG_GET_CERT_DIR(
     char **                             cert_dir);
 
 globus_result_t
-globus_gsi_sysconfig_get_user_cert_filename_win32(
+GLOBUS_GSI_SYSCONFIG_GET_USER_CERT_FILENAME(
     char **                             user_cert_filename,
     char **                             user_key_filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_host_cert_filename_win32(
+GLOBUS_GSI_SYSCONFIG_GET_HOST_CERT_FILENAME(
     char **                             host_cert_filename,
     char **                             host_key_filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_service_cert_filename_win32(
+GLOBUS_GSI_SYSCONFIG_GET_SERVICE_CERT_FILENAME(
     char *                              service_name,
     char **                             service_cert_filename,
     char **                             service_key_filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_proxy_filename_win32(
+GLOBUS_GSI_SYSCONFIG_GET_PROXY_FILENAME(
     char **                             proxy_filename,
     globus_gsi_proxy_file_type_t        proxy_file_type);
 
 globus_result_t
-globus_gsi_sysconfig_get_signing_policy_filename_win32(
+GLOBUS_GSI_SYSCONFIG_GET_SIGNING_POLICY_FILENAME(
     X509_NAME *                         ca_name,
     char *                              cert_dir,
     char **                             signing_policy_filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_ca_cert_files_win32(
+GLOBUS_GSI_SYSCONFIG_GET_CA_CERT_FILES(
     char *                              ca_cert_dir,
     globus_fifo_t *                     ca_cert_list);
 
 globus_result_t
-globus_gsi_sysconfig_get_current_working_dir_win32(
+GLOBUS_GSI_SYSCONFIG_GET_CURRENT_WORKING_DIR(
     char **                             working_dir);
 
 globus_result_t
-globus_gsi_sysconfig_make_absolute_path_for_filename_win32(
-    char *                              filename,
-	char **								absolute_path);
-
-globus_result_t
-globus_gsi_sysconfig_split_dir_and_filename_win32(
-    char *                              full_filename,
-    char **                             dir_string,
-    char **                             filename_string);
-
-globus_result_t
-globus_gsi_sysconfig_remove_all_owned_files_win32(
-    char *                              default_filename);
-
-globus_result_t
-globus_gsi_sysconfig_is_superuser_win32(
-    int *                               is_superuser);
-
-globus_result_t
-globus_gsi_sysconfig_get_user_id_string_win32(
-    char **                             user_id_string);
-
-globus_result_t
-globus_gsi_sysconfig_get_username_win32(
-    char **                             username);
-
-globus_result_t
-globus_gsi_sysconfig_get_proc_id_string_win32(
-    char **                             proc_id_string);
-
-globus_result_t
-globus_gsi_sysconfig_get_gridmap_filename_win32(
-    char **                             filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_authz_conf_filename_win32(
-    char **                             filename);
-
-
-#else /* if WIN32 is not defined, then define the unix functions */
-
-globus_result_t
-globus_gsi_sysconfig_set_key_permissions_unix(
-    char *                              filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_home_dir_unix(
-    char **                             home_dir);
-
-globus_result_t
-globus_gsi_sysconfig_file_exists_unix(
-    const char *                        filename);
-
-globus_result_t
-globus_gsi_sysconfig_dir_exists_unix(
-    const char *                        filename);
-
-globus_result_t
-globus_gsi_sysconfig_check_keyfile_unix(
-    const char *                        filename);
-
-globus_result_t
-globus_gsi_sysconfig_check_certfile_unix(
-    const char *                        filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_cert_dir_unix(
-    char **                             cert_dir);
-
-globus_result_t
-globus_gsi_sysconfig_get_user_cert_filename_unix(
-    char **                             user_cert_filename,
-    char **                             user_key_filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_host_cert_filename_unix(
-    char **                             host_cert_filename,
-    char **                             host_key_filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_service_cert_filename_unix(
-    char *                              service_name,
-    char **                             service_cert_filename,
-    char **                             service_key_filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_proxy_filename_unix(
-    char **                             user_proxy,
-    globus_gsi_proxy_file_type_t        proxy_file_type);
-
-globus_result_t
-globus_gsi_sysconfig_get_signing_policy_filename_unix(
-    X509_NAME *                         ca_name,
-    char *                              cert_dir,
-    char **                             signing_policy_filename);
-
-globus_result_t
-globus_gsi_sysconfig_get_ca_cert_files_unix(
-    char *                              ca_cert_dir,
-    globus_fifo_t *                     ca_cert_list);
-
-globus_result_t
-globus_gsi_sysconfig_get_current_working_dir_unix(
-    char **                             working_dir);
-
-globus_result_t
-globus_gsi_sysconfig_make_absolute_path_for_filename_unix(
+GLOBUS_GSI_SYSCONFIG_MAKE_ABSOLUTE_PATH_FOR_FILENAME(
     char *                              filename,
     char **                             absolute_path);
 
 globus_result_t
-globus_gsi_sysconfig_split_dir_and_filename_unix(
+GLOBUS_GSI_SYSCONFIG_SPLIT_DIR_AND_FILENAME(
     char *                              full_filename,
     char **                             dir_string,
     char **                             filename_string);
 
 globus_result_t
-globus_gsi_sysconfig_remove_all_owned_files_unix(
+GLOBUS_GSI_SYSCONFIG_REMOVE_ALL_OWNED_FILES(
     char *                              default_filename);
 
 globus_result_t
-globus_gsi_sysconfig_is_superuser_unix(
+GLOBUS_GSI_SYSCONFIG_IS_SUPERUSER(
     int *                               is_superuser);
 
 globus_result_t
-globus_gsi_sysconfig_get_user_id_string_unix(
+GLOBUS_GSI_SYSCONFIG_GET_USER_ID_STRING(
     char **                             user_id_string);
 
 globus_result_t
-globus_gsi_sysconfig_get_username_unix(
+GLOBUS_GSI_SYSCONFIG_GET_USERNAME(
     char **                             username);
 
 globus_result_t
-globus_gsi_sysconfig_get_proc_id_string_unix(
+GLOBUS_GSI_SYSCONFIG_GET_PROC_ID_STRING(
     char **                             proc_id_string);
 
 globus_result_t
-globus_gsi_sysconfig_get_gridmap_filename_unix(
+GLOBUS_GSI_SYSCONFIG_GET_GRIDMAP_FILENAME(
     char **                             filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_authz_conf_filename_unix(
+GLOBUS_GSI_SYSCONFIG_GET_AUTHZ_CONF_FILENAME(
     char **                             filename);
 
 globus_result_t
-globus_gsi_sysconfig_get_gaa_conf_filename_unix(
-    char **                             filename);
-
-#endif /* WIN32 */
-
-globus_result_t
-globus_gsi_sysconfig_get_unique_proxy_filename(
+GLOBUS_GSI_SYSCONFIG_GET_UNIQUE_PROXY_FILENAME(
     char **                             unique_filename);
 
+globus_result_t
+GLOBUS_GSI_SYSCONFIG_GET_VHOST_CRED_DIR(
+    char                              **dir_name_out);
+
 #ifdef __cplusplus
 }
 #endif
